#
#  Copyright 1996-2008 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::OS::linux - Linux specific configuration information
#
package Security::OS::linux;

use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &check );

sub init {
	print ( STDERR  "In Security::OS::linux::init()\n") if ( $main::opts{'d'} );

	$main::showmount = '/usr/sbin/showmount';
	$main::exportsfile = '/etc/exports';
	$main::securefile='/etc/securetty';
	$main::kerneldir='/lib/modules';
	$main::sudofile = '/etc/sudoers';
}

sub check {
	print ( STDERR  "In Security::OS::linux::check()\n") if ( $main::opts{'d'} );

	&Security::rootlogin::check_securettys() 
		if ( defined &Security::rootlogin::check_securettys );
}

1;

__END__

=head1 NAME

Security::OS::linux

=head1 SYNOPSIS

Security::OS::linux::init();

Security::OS::linux::check();

=head1 DESCRIPTION

Sets variables for OS specific commands.

=head1 API

Defines the following API calls

=over 4

=item C<init()>

Init sets the following global variables:

=over 4

=item C<$main::showmount>

The location of the showmount command, used in the C<Security::exports> module.

=item C<$main::exportsfile>

The location of the exports file, used in C<Security::exports> module.

=item C<$main::sudofile>

The location of F<sudoers> file, used in C<Security::sudo> module.

=item C<$main::kerneldir>

The location of the kernel loadable modules, used in C<Security::kernel>
module.

=item C<$main::securefile>

The location of the list of ports root is allowed in on, used in
C<Security::rootlogin> module.

=back

=item C<check()>

Calls C<Security::rootlogin::check_securetty()> to check what root ports are
configured and compares it to what ports we know about.

=back

=cut

