#
#  Copyright 1996-2008 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::kernel - loadable kernel modules control module
#
package Security::kernel;

use Security::find;
use Security::db;
use Exporter;
use POSIX;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &print() );

our (%kernelperms);

sub init {
	print ( STDERR  "In Security::kernel::init()\n") if ( $main::opts{'d'} );

	&Security::find::add_wanted (\&kernel_wanted);
}

# Added $kerneldir checks based on the SANS98 Conference
sub kernel_wanted {
	if ( ! -l $File::Find::name && -f $File::Find::name ) {
		if ( defined $main::kerneldir && 
			$File::Find::name =~ /^$main::kerneldir/ ) {

			my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$curbytes) = 
				&Security::find::get_stat($File::Find::name, 'lstat');

			&Security::db::verify($File::Find::name);

			# If the file is world writeable, then flag this case too
			$kernelperms{$File::Find::name} = 1
				if ( $mode & &S_IWOTH() );
		}
	}
}

sub print {
	print ( STDERR  "In Security::kernel::print()\n") if ( $main::opts{'d'} );

	&main::print_data ("\n\nchecking for world writable kernel modules:\n", %kernelperms);
}

1;

__END__

=head1 NAME

Security::kernel - kernel loadable module file checks

=head1 SYNOPSIS

Security::kernel::init()

Security::kernel::print()

=head1 DESCRIPTION

Checks the checksum and file mode of any file listed under
C<$main::kerneldir>.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Calls C<add_wanted (\&kernel_wanted)> to implement the list of directories
where will find kernel loadable modules.

=item C<print()>

Calls C<print_data ()> to print out the list of kernel modules that were
world writable.

=back

=head1 HISTORY

The idea for this came from the SANS 1998 Security conference in Orlando, FL.

=head1 TODO

Convert C<$main::kerneldir> to C<@main::kerneldirs>.

=head1 SEE ALSO

L<Security::find>

L<Security::db>

=cut

