#
#  Copyright 1996-2008 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::pkgchk - Solaris pkgchk control module
#
package Security::pkgchk;

use Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &check() &print() );

our (%perms, $pkgchk);

sub init {
	print ( STDERR "In Security::pkgchk::init()\n") if ( $main::opts{'d'} );

	# Commented out because this module is not finished
#	$pkgchk = '/usr/sbin/pkgchk' if ( -f '/usr/sbin/pkgchk' );
}

sub check {
	my ($dir);
	print ( STDERR "In Security::pkgchk::check()\n") if ( $main::opts{'d'} );

	return if ( ! defined $pkgchk );

	print ( STDERR "\tRunning cmd $pkgchk -n -q\n") if ( $main::opts{'d'} );
	if (open (FP, "$pkgchk -n -q 2>&1 |")) {
		while (<FP>) {
			chop;
			if ( $_ =~ /ERROR: /o ) {
				$dir = $_;
				$dir =~ s/^ERROR: //go;
				$perms{$dir} = 1;
			} elsif ( length ($dir) > 1 ) {
				s/permissions /mode /;
				s/group name /group /;
				s/\> expected \</:/;
				s/ actual//;
				s/\</(/;
				s/\>/)/;
				if ( exists $perms{$dir} ) {
					$perms{$dir}=($perms{$dir} eq '1')
						? $_ : $perms{$dir} . $_;
					$perms{$dir} =~ s/  / /g;
				}
			} else {
				print ( STDERR "\tDo not know what to do with $_\n\tdir = $dir\n") if ( $main::opts{'d'} );
			}
		}
		close FP;
	} else {
		print ( STDERR "ERROR: Running cmd $pkgchk -n -q\n") if ( $main::opts{'d'} );
	}
}

sub print {
	print ( STDERR  "In Security::pkgchk::print()\n") if ( $main::opts{'d'} );

	&main::print_data ("\n\nchecking pkgchk command output:\n", %perms);
}

1;

__END__

=head1 NAME

Security::pkgchk - Solaris pkgchk control module

=head1 SYNOPSIS

Security::pkgchk::init();

Security::pkgchk::check();

Security::pkgchk::print();

=head1 DESCRIPTION

This module will take the output from pkgchk and standardizes the output.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Looks for the location of the C<pkgchk(1)> command.

=item C<check()>

Runs the C<pkgchk(1)> command and processes the output.

=item C<print()>

Calls C<print_data ()> to print out the mismatches from the C<pkgchk(1)>
output.

=head1 TODO

Need to finish this module.

=head1 SEE ALSO

L<pkgchk(1)>

=cut

