#
#  Copyright 1996-2008 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::suid - set uid/gid control module
#
package Security::suid;

use Security::find;
use Security::db;
use Exporter;
use POSIX;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( &init() &print() );

our (%suidperms);

sub init {
	print ( STDERR  "In Security::suid::init()\n") if ( $main::opts{'d'} );

	&Security::find::add_wanted (\&suid_wanted);
}

# Check the permissions and maybe the checksum of all suid/sgid files.
# From the FreeBSD /etc/security script
sub suid_wanted {
	my ($currsum);

	if ( -x $File::Find::name && -f $File::Find::name &&
		! -l $File::Find::name &&
		( -u $File::Find::name || -g $File::Find::name)) {
		my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$curbytes) = 
			&Security::find::get_stat($File::Find::name, 'lstat');

		&Security::db::verify($File::Find::name);

		# If the file is world writeable, then flag this case too
		$suidperms{$File::Find::name} = 1
			if ( $mode & &S_IWOTH() );
	}
}

sub print {
	print ( STDERR  "In Security::suid::print()\n") if ( $main::opts{'d'} );

	&main::print_data ("\n\nchecking for world writable suid/sgid programs:\n", %suidperms);
}

1;

__END__

=head1 NAME

Security::suid - set uid/gid control module

=head1 SYNOPSIS

Security::suid::init();

Security::suid::print();

=head1 DESCRIPTION

Checks all setuid and setgid scripts on the file system, including owner
mode and checksum.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Calls C<Security::find::add_wanted> to register the C<suid_wanted> sub routine.

=item C<print()>

Calls C<print_data ()> to print out the list of setuid or setgid commands
that are world writable.

=back

=head1 HISTORY

The idea of looking for checking setuid and setgid scripts was suggested in
BSD 4.4 security script.

=head1 SEE ALSO

L<Security::find>

L<Security::db>

=cut

